import EventEmitter from 'node:events';
import { Writable } from 'node:stream';
import { handleData } from './internals.js';
import { defaultOptions, FastImageError } from './models.js';
export class FastImageStream extends Writable {
    constructor(options){
        super(options);
        this.threshold = options.threshold ?? defaultOptions.threshold;
        this.buffer = Buffer.alloc(0);
        this.start = process.hrtime.bigint();
        this.finished = false;
    }
    analyze(chunk) {
        this.buffer = Buffer.concat([
            this.buffer,
            chunk
        ]);
        this.finished = handleData(this.buffer, undefined, this.threshold, this.start, new EventEmitter(), (error, data)=>{
            if (error) {
                this.emit('error', error);
            } else {
                this.emit('info', data);
            }
            this.destroy();
        });
    }
    _write(chunk, _e, cb) {
        this.analyze(chunk);
        cb();
    }
    /* c8 ignore start  */ _writev(chunks, cb) {
        for (const { chunk  } of chunks){
            this.analyze(chunk);
        }
        cb();
    }
    /* c8 ignore stop  */ _final(cb) {
        /* c8 ignore next 4 */ if (this.finished) {
            cb();
            return;
        }
        cb(new FastImageError('Unsupported data.', 'UNSUPPORTED'));
    }
}
